#
# spec file for package mate-utils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname_dict libmatedict
%define sover_dict 6
%define d_applet   0
%define _version 1.28

Name:           mate-utils
Version:        1.28.0
Release:        1.3
Summary:        MATE Desktop utilities
License:        GFDL-1.1-only AND GPL-2.0-or-later AND LGPL-2.0-or-later
Group:          System/X11/Utilities
URL:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  inkscape
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  popt-devel
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gdk-wayland-3.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(gtk-layer-shell-0)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libgtop-2.0)
BuildRequires:  pkgconfig(libmatepanelapplet-4.0) >= %{_version}
BuildRequires:  pkgconfig(mate-desktop-2.0) >= %{_version}
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(udisks2)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(zlib)
%glib2_gsettings_schema_requires
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} >= 150200
BuildRequires:  rsvg-convert
%else
BuildRequires:  rsvg-view
%endif

%description
This package provides all the tools bundled with MATE utilities:
 - mate-disk-image-mounter, a disc image mounter.
 - mate-disk-usage-analyzer, a disc usage analyser.
 - mate-dictionary, a program which can look up definitions of words.
 - mate-search-tool, with which one can find files by name or content.
 - mate-system-log, a log viewing application.
 - mate-screenshot, a tool to take desktop screenshots and save them.

%package common-lang
Summary:        Languages for MATE utilities
License:        GFDL-1.1-only AND GPL-2.0-or-later AND LGPL-2.0-or-later
Group:          System/X11/Utilities
Provides:       mate-dictionary-lang = %{version}
Provides:       mate-disk-image-mounter-lang = %{version}
Provides:       mate-disk-usage-analyzer-lang = %{version}
Provides:       mate-screenshot-lang = %{version}
Provides:       mate-search-tool-lang = %{version}
Provides:       mate-system-log-lang = %{version}
BuildArch:      noarch

%description common-lang
Provides common translations shared by Caja extensions

%package -n mate-search-tool
Summary:        MATE Search Tool
License:        GPL-2.0-or-later
Group:          System/X11/Utilities
Requires:       mate-desktop-gschemas >= %{_version}
Recommends:     %{name}-doc
Recommends:     mate-search-tool-lang

%description -n mate-search-tool
This is the MATE Seach Tool as shipped with the MATE utilities. It uses
command-line tools such as find and locate to get results.

%package -n mate-disk-image-mounter
Summary:        MATE disk image mounter
License:        GPL-2.0-or-later
Group:          System/X11/Utilities
Recommends:     %{name}-doc
Recommends:     mate-disk-image-mounter-lang

%description -n mate-disk-image-mounter
This is the MATE Disk Image Mounter as shipped with the MATE
utilities. mate-disk-image-mounter shows up in Caja for .ISO files
to be conviniently mounted.

%package -n mate-disk-usage-analyzer
Summary:        MATE disk usage analyser
License:        GPL-2.0-or-later
Group:          System/X11/Utilities
Recommends:     %{name}-doc
Recommends:     mate-disk-usage-analyzer-lang

%description -n mate-disk-usage-analyzer
This is the MATE Disk Usage Analyzer as shipped with the MATE utilities.
mate-disk-usage-analyzer is able to scan either specific directories or
the wholefilesystem, in order to give the user a graphical tree representation
including each directory size or percentage in the branch.
It also auto-detects in real-time any change made to your home
directory as far as any mounted/unmounted device.

%package -n mate-dictionary
Summary:        MATE dictionary
License:        GPL-2.0-or-later
Group:          System/X11/Utilities
Requires:       mate-desktop-gschemas >= %{_version}
Recommends:     %{name}-doc
Recommends:     mate-dictionary-lang

%description -n mate-dictionary
This is the MATE dictionary as shipped with the MATE utilities.
mate-dictionary is a program which can look up the definition of
words

%package -n mate-system-log
Summary:        MATE system log viewer
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          System/X11/Utilities
Requires:       mate-desktop-gschemas >= %{_version}
Recommends:     %{name}-doc
Recommends:     mate-system-log-lang

%description -n mate-system-log
This is the MATE system log viewer as shipped with the MATE utilities.
mate-system-log is a program which can view logs generated by the
operating system.

%package -n mate-screenshot
Summary:        MATE screenshot maker
License:        GPL-2.0-or-later
Group:          System/X11/Utilities
Recommends:     %{name}-doc
Recommends:     mate-screenshot-lang

%description -n mate-screenshot
This is the MATE screenshot maker as shipped with the MATE utilities.
mate-screenshot is a program which cantake desktop screenshots and
save them.

%package -n %{soname_dict}%{sover_dict}
Summary:        Library to look up words in dictionary sources
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n %{soname_dict}%{sover_dict}
The matedict library is an engine to look up words in dictionary sources.

%package -n %{soname_dict}-devel
Summary:        Header files for MATE's dictionary library
License:        GPL-2.0-or-later
Group:          Development/Libraries/X11
Requires:       %{soname_dict}%{sover_dict} = %{version}

%description -n %{soname_dict}-devel
The matedict library is an engine to look up words in dictionary sources.
This package contains development files for libmatedict.

%package doc
Summary:        Documentation how to mate-utils
License:        GFDL-1.1-only AND GPL-2.0-or-later AND LGPL-2.0-or-later
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package contains the documentation for mate-utils

%prep
%autosetup

# Do not build the pt lingua for the search tool help to solve build issues.
sed -i 's/^\(IGNORE_HELP_LINGUAS =\)/\1 pt/' gsearchtool/help/Makefile.am

%build
NOCONFIGURE=1 mate-autogen
%configure  --disable-static \
            --libexecdir=%{_libexecdir}/%{name} \
            --with-x \
            --enable-ipv6=yes \
            --enable-debug=yes \
            --enable-wayland \
            --enable-in-process \
            --enable-gtk-doc \
            --enable-gtk-doc-html \
            --enable-gtk-doc-pdf
%make_build

%install
%make_install
%find_lang %{name}
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}%{_datadir}

%suse_update_desktop_file mate-disk-usage-analyzer
%suse_update_desktop_file mate-dictionary
%suse_update_desktop_file mate-search-tool
%suse_update_desktop_file mate-system-log
%suse_update_desktop_file mate-screenshot

%post -n %{soname_dict}%{sover_dict} -p /sbin/ldconfig
%postun -n %{soname_dict}%{sover_dict} -p /sbin/ldconfig

%files -n mate-disk-image-mounter
%license COPYING*
%doc AUTHORS NEWS README.md ChangeLog
%{_bindir}/mate-disk-image-mounter
%{_datadir}/applications/mate-disk-image-mounter.desktop

%files -n mate-disk-usage-analyzer
%license COPYING*
%doc AUTHORS NEWS README.md ChangeLog
%exclude %{_datadir}/help/C/mate-disk-usage-analyzer/
%{_bindir}/mate-disk-usage-analyzer
%{_datadir}/glib-2.0/schemas/org.mate.disk-usage-analyzer.gschema.xml
%{_datadir}/applications/mate-disk-usage-analyzer.desktop
%{_datadir}/icons/hicolor/*/apps/mate-disk-usage-analyzer.*
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/mate-disk-usage-analyzer.appdata.xml
%{_mandir}/man?/mate-disk-usage-analyzer.?%{?ext_man}

%files -n mate-dictionary
%license COPYING*
%doc AUTHORS NEWS README.md ChangeLog
%exclude %{_datadir}/help/C/mate-dictionary/
%{_bindir}/mate-dictionary
#%{_datadir}/dbus-1/services/org.mate.panel.applet.DictionaryAppletFactory.service
%{_datadir}/glib-2.0/schemas/org.mate.dictionary.gschema.xml
%{_datadir}/mate-dictionary/
%dir %{_datadir}/mate-panel/
%dir %{_datadir}/mate-panel/applets/
%{_datadir}/mate-panel/applets/org.mate.DictionaryApplet.mate-panel-applet
#%dir %{_libexecdir}/mate-utils/
#%{_libexecdir}/mate-utils/mate-dictionary-applet
%{_datadir}/applications/mate-dictionary.desktop
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/mate-dictionary.appdata.xml
%{_mandir}/man?/mate-dictionary.?%{?ext_man}
%dir %{_libdir}/mate-utils
%{_libdir}/mate-utils/libmate-dictionary-applet.so.*

%files -n mate-screenshot
%license COPYING*
%doc AUTHORS NEWS README.md ChangeLog
%{_bindir}/mate-panel-screenshot
%{_bindir}/mate-screenshot
%{_datadir}/glib-2.0/schemas/org.mate.screenshot.gschema.xml
%{_datadir}/applications/mate-screenshot.desktop
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/mate-screenshot.appdata.xml
%{_mandir}/man?/mate-panel-screenshot.?%{?ext_man}
%{_mandir}/man?/mate-screenshot.?%{?ext_man}

%files -n mate-search-tool
%license COPYING*
%doc AUTHORS NEWS README.md ChangeLog
%exclude %{_datadir}/help/C/mate-search-tool/
%{_bindir}/mate-search-tool
%{_datadir}/glib-2.0/schemas/org.mate.search-tool.gschema.xml
%{_datadir}/applications/mate-search-tool.desktop
%{_datadir}/pixmaps/mate-search-tool/
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/mate-search-tool.appdata.xml
%{_mandir}/man?/mate-search-tool.?%{?ext_man}

%files -n mate-system-log
%license COPYING*
%doc AUTHORS NEWS README.md ChangeLog
%exclude %{_datadir}/help/C/mate-system-log/
%{_bindir}/mate-system-log
%{_datadir}/applications/mate-system-log.desktop
%{_datadir}/glib-2.0/schemas/org.mate.system-log.gschema.xml
%{_datadir}/icons/hicolor/*/apps/mate-system-log*
%{_mandir}/man?/mate-system-log.?%{?ext_man}

%files -n %{soname_dict}%{sover_dict}
%{_libdir}/%{soname_dict}.so.%{sover_dict}*

%files -n %{soname_dict}-devel
%doc %{_datadir}/gtk-doc/html/mate-dict/
%{_includedir}/mate-dict/
%{_datadir}/mate-dict/
%{_libdir}/%{soname_dict}.so
%{_libdir}/mate-utils/libmate-dictionary-applet.so
%{_libdir}/pkgconfig/mate-dict.pc

%files common-lang -f %{name}.lang
%exclude %{_datadir}/help/*

%files doc
%doc %{_datadir}/help/C/*/

%changelog
* Mon Mar 25 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.28.0
  * Translations update
  * replace deprecated gtk_image_menu_item*
  * dictionary applet: fix in-process build warning
  * fix warnings in id, uk and ru translations
  * wayland: dictionary applet: confine popup dialog to monitor dimensions
  * wayland: dictionary: Make the panel applet usable in wayland
  * Wayland: Fix position and behavior of dictionary applet popup window
  * dictionary applet: allow building in-process
  * Remove init_stock_icons code and replace gtk_drag_set_icon_stock with
    gtk_drag_set_icon_name
  * mate-dictionary: Replace deprecated functions fix compilation warnings
  * baobab-remote-connect-dialog: fix -Wformat-nonliteral warning
  * logview: Replace deprecated functions fix compilation warnings
* Sun May 14 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.1
  * Fix memory leak
- Add mate-desktop-gschemas as Requires for mate-dictionary (boo#1211327)
* Thu Aug 26 2021 Hillwood Yang <hillwood@opensuse.org>
- Split doc package
* Sun Aug 22 2021 Jan Engelhardt <jengelh@inai.de>
- Trim em dash grammar from descriptions.
* Wed Aug 11 2021 Hillwood Yang <hillwood@opensuse.org>
- update version to 1.26.0
  * update copyright to 2021
  * tx: update resource
  * travis-Ci: use libera.chat as notification server
  * tx: sync with transifex
  * release 1.26.0
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0 (changes since 1.23.0):
  * Add MATE Disk Image Mounter utility.
  * WARN_CFLAGS makes MAINTAINER_CFLAGS obsolete for now.
  * Use MATE_DEBUG_CHECK for setting compiler debug flags.
  * Print compiler warning flags in summary.
  * Add WARN_CFLAGS to CFLAGS.
  * logview: Fix infinite loop parsing logs containing at least one
    line.
  * Add hicolor_apps_24x24_mate-system-log.png.
  * Install hicolor_apps_24x24_mate-disk-usage-analyzer.png.
  * Avoid g_type_class_add_private.
  * logview: i18n date format in side pane.
  * logview: Use preferred date&time representation for current
    locale.
  * mate-disk-usage-analyzer: Remove blank space before right
    parenthesis.
  * Add scroll tabs with mouse wheel.
  * gettext: Fix locale dir.
  * Migrate from intltool to gettext.
  * Use gresources for UI files.
  * Avoid redundant redeclarations.
  * Fix build using the -fno-common flag.
  * Update translations.
- Add a mate-disk-image-mounter package for the newly added
  utility.
- Drop support for old openSUSE versions.
* Wed Oct 23 2019 ro@suse.de
- fix build-requires for factory/tumbleweed
  rsvg-convert tool is now in rsvg-convert package
* Thu Jul 18 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.23.0:
  * Update translations.
  * Remove unused variables
  * Make inkscape and rsvg-convert optional
  * mate-screenshot: Variable is assigned a value that is never used
  * gdict-applet: Variable 'detail' is allocated memory that is never used
  * logview-prefs: Variable 'removed' is assigned a value that is never used
  * Fix -Werror=cast-function-type with GCC 8
  * Improve performance by removing unused assignments
- remove patch:
  * mate-utils-gtk-3.20.patch: we don't support gtk3.22 anymore
- build require gtk >= 3.22, glib >= 2.50 and gio >= 2.50
* Sun May 12 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.22.1:
  * Fix -Werror=cast-function-type with GCC 8.
  * mate-disk-usage-analyzer: Fix a memory leak.
  * GEN png icons from svg files.
  * Update documenters in the about dialogue.
  * mate-dictionary: Use g_strjoin to build licence text.
  * Use program-name and title in gtk_show_about_dialog call.
  * help: Update copyright.
  * Update translations.
- Rebase mate-utils-gtk-3.20.patch.
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * Add support for non-interactive screenshot directly to
    clipboard.
  * Avoid deprecated GtkStock.
  * mate-dictionary: Fix memory leak.
  * Replace deprecated gtk_menu_popup.
  * screenshot: Replace deprecated gdk_flush.
  * dictionary: Replace deprecated gdk_flush.
  * dictionary: Replace deprecated GtkFontButton accessors.
  * baobab help: Terminal command updated to
    mate-disk-usage-analyzer.
  * baobab-chart: Avoid deprecated gtk_style_context_set_background.
  * gsearchtool: Avoid deprecated gtk_window_set_wmclass.
  * Make translatable the copyright in the About dialogue.
  * help: Bump docbook 4.5.
  * eggsmclient: Avoid deprecated g_type_class_add_private.
  * Move appdata to the metainfo/ directory.
  * Update translations.
- Rebase mate-utils-gtk-3.20.patch.
- Do not build the pt lingua for the search tool help to solve
  build issues.
* Wed Dec 26 2018 sor.alexei@meowr.ru
- Update to version 1.20.2:
  * Disable deprecation warnings for distcheck.
  * Use make functions for HELP_LINGUAS.
  * Replace -Dokumentationsprojekt with Documentation Project.
  * Fix spelling and grammar mistakes.
  * Update translations.
* Fri Jun 22 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * Update translations.
* Thu Mar 22 2018 crrodriguez@opensuse.org
- BuildRequire atk, pango, cairo, x11, ice explicitly.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * Add screenshot support for HiDPI displays.
  * Avoid deprecated gdk_screen_get_monitor_,
    gdk_screen_width/height(), gdk_screen_get_width/height(),
    gdk_screen_get_n_monitors(), gdk_screen_make_display_name(),
    gdk_screen_get_number(), gdk_screen_get_active_window()
    functions.
  * screenshot, dictionary: Avoid deprecated GdkDevice members.
  * don't use deprecated gtk_show_uri()
  * searchtool & logview: Avoid deprecated GtkAlignment.
  * An implementation of WidthOfScreen and HeightOfScreen.
  * mate-screenshot: Add a New button
  * screenshot-save.c: Fix build warnings with 'pipe', 'write' and
    'read'.
  * Add a style class logview-window.
  * Update translations.
- Add mate-utils-gtk-3.20.patch: Restore GLib 2.48 and GTK+ 3.20
  support.
* Wed Oct 25 2017 sor.alexei@meowr.ru
- Update to version 1.18.3:
  * disk-usage-analyzer: Make zoom with mousewheel work on chart.
  * disk-usage-analyzer: Various UI fixes.
  * screenshot: Remove some buggy code to fix possible crash.
  * baobab/logview/dictionary: Add our copyright to the About
    dialogue.
  * Update translations.
* Sun May  7 2017 sor.alexei@meowr.ru
- Update to version 1.18.2:
  * Fix showing busy cursor when saving area screenshot.
  * Update translations.
* Tue Apr  4 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * screenshot: Do not translate the timestamp in the filename.
  * mate-dictionary: Include a correct header.
  * Update translations.
- Remove mate-utils-fix-include.patch: fixed upstream.
* Mon Mar 27 2017 sor.alexei@meowr.ru
- Add mate-utils-fix-include.patch: Include a correct header in
  mate-dictionary (commit a3c64fd).
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Build: Require mate-panel >= 1.17.
  * Move to GTK+3 (require GTK+ >= 3.14), drop the GTK+2 code and
  - -with-gtk build option.
  * Fix occasional distcheck breakage.
  * Some code cleanups.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Add --version command line option to mate-screenshot.
  * GTK+3: Fix a mate-dictionary segfault with Gtk 3.21.
  * GTK+3: Fix lots of deprecations in all applications.
  * Update translations.
* Sun Aug 14 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * Require proper GTK+ version in mate-dict.pc file.
  * Some assorted fixes.
  * Make distcheck use currently selected GTK+ version.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Use hyphens instead of colons in screenshot filenames by
    default.
  * Some more fixes and cleanups.
  * Update translations.
  * Fix Changelog generation.
* Thu Jan 28 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * GTK+3: Fix a lot of deprecations and some UI issues.
  * Disable effects and delay options in mate-screenshot UI when
    launched with -ai command line argument.
  * Don't use -Werror flag in build.
  * Drop MateConf migration scripts.
* Mon Jan 11 2016 sor.alexei@meowr.ru
- Add missing mate-desktop-gschemas dependency to
  mate-search-tool, and mate-system-log.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0.
* Thu Oct 15 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Add application icon to mate-system-log.
  * Add timestamp instead of window name to screenshot filenames by
    default.
  * Have dictionary applet background automatically painted.
  * Translation fixes for gsettings schemas.
  * Some more fixes and cleanups (including source tree
    reorganisation).
* Wed Sep  2 2015 sor.alexei@meowr.ru
- Update to 1.10.3:
  * Fixed silent rules option by dropping obsolete "shave" stuff.
  * Make mate-system-log remember the active log on exit.
  * Fix potential crash in mate-system-log.
  * Various other bugfixes in mate-system-log.
  * Remove dead spanish server entry from mate-dictionary.
  * Fix mate-dictionary's command-line options and manpage.
  * Make Ctrl+A and Ctrl+C work in mate-dictionary's search field.
* Sat Jul 11 2015 sor.alexei@meowr.ru
- Update to version 1.10.2:
  * Several help fixes.
* Thu Jun 18 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Fix gschema translations.
* Thu May  7 2015 sor.alexei@meowr.ru
- Update to 1.10.0 (changes since 1.9.1):
  * Use explicit names in .desktop files.
  * Fix GLib >= 2.43 compatibility.
  * Update translations.
- Spec cleanup.
* Fri Jan 23 2015 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  + Bug fixes release
* Thu Dec 11 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + Add GTK3 support
- Fix version requirements
* Fri Oct  3 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + Added keywords key to .desktop files
  + Fixed several man pages
  + Fixed gsearchtool format-security warning
* Sat Mar 22 2014 p.drouand@gmail.com
- Remove forgotten mate-doc-utils require
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Thu Feb 20 2014 p.drouand@gmail.com
- Update to version 1.7.90 (unstable)
  + use yelp-tools instead of mate-doc-utils
  + bugfixes
- All tools live in their own package now
- Add itstool requires; new upstream dependency
- Remove useless xz requires
* Mon Jan  6 2014 p.drouand@gmail.com
- Update to version 1.6.1
  + disable masking for area or window screenshots
  + Fix Sun GNOME Documentation Team references
  + screenshot: do not segfault when taking a window picture with no
    delay
  + Update AC_INIT_AUTOMAKE for make dist
  + Remove files pulled in automatically
  + Correct sgml filename
  + Correct name in about dialog
  + mate-screenshot: Fix save path selection
    Closes #32 (https://github.com/mate-desktop/mate-utils/issues/32)
    Fix from https://bugzilla.gnome.org/show_bug.cgi?id=579232
  + Fix incorrect FSF addresses
  + Use mate-disk-usage-analyzer icon instead of baobab
  + Fix name of libmatedict in mate-dict.pc.in
    Closes #6 (https://github.com/mate-desktop/mate-utils/issues/6)
  + change installation path of mate-disk-usage-analyzer icon to hicolor
- Add gtk-doc documentation of mate-dict to filelist of devel subpackage
- Remove useless scrollkeeper build dependency
* Thu Sep 19 2013 johann.luce@wanadoo.fr
- Fix %%exclude problem for factory
* Wed Apr  3 2013 p.drouand@gmail.com
- Update to version 1.6.0
  + no changes since 1.5.1
* Sun Mar 24 2013 p.drouand@gmail.com
- Update to version 1.5.1
  + fix missing static void keywords in baobab
  + remove comment on mate-screenshot manpage
  + fix libgdict makefile
  + update makefile for automake 1.13
- Remove merged patchs on upstream release:
  + Fix-missing-static-void-keywords-in-baobab.patch
  + Remove-comment-on-manpage.patch
* Sun Feb 17 2013 hillwood@linuxfans.org
- change group of devel package as Development/Libraries/Other
* Sat Feb  9 2013 p.drouand@gmail.com
- add Fix-missing-static-void-keywords-in-baobab.patch; fix build for Factory
- add  Remove-comment-on-manpage.patch ; fix build for Factory
* Mon Oct  1 2012 nmo.marques@gmail.com
- rework mate-utils-1.4.0-fix_pointer.patch; merged upstream
- add missing descriptions and cleanups
* Wed Sep 12 2012 nmo.marques@gmail.com
- add mate-utils-1.4.0-fix_pointer.patch: fix build for 1210
* Tue Sep 11 2012 nmo.marques@gmail.com
- initial package from version 1.4.0
